@@ -21,13 +21,16 @@ function logging.email(params)
     return nil, "'rcpt' parameter is required"
   end
 
-  local timestampPattern = params.timestampPattern
+  local timestampPattern = params.timestampPattern or logging.defaultTimestampPattern()
+  local logPatterns = logging.buildLogPatterns(params.logPatterns, params.logPattern)
+  local startLevel = params.logLevel or logging.defaultLevel()
 
   return logging.new( function(self, level, message)
-    local s = logging.prepareLogMsg(params.logPattern, os.date(timestampPattern), level, message)
+    local dt = os.date(timestampPattern)
+    local s = logging.prepareLogMsg(logPatterns[level], dt, level, message)
     if params.headers.subject then
       params.headers.subject =
-        logging.prepareLogMsg(params.headers.subject, os.date(timestampPattern), level, message)
+        logging.prepareLogMsg(params.headers.subject, dt, level, message)
     end
     local msg = { headers = params.headers, body = s }
     params.source = smtp.message(msg)
@@ -38,7 +41,7 @@ function logging.email(params)
     end
 
     return true
-  end)
+  end, startLevel)
 end
 
 return logging.email
