@@ -72,8 +72,9 @@ end
 
 function logging.rolling_file(params, ...)
   params = logging.getDeprecatedParams({ "filename", "maxFileSize", "maxBackupIndex", "logPattern" }, params, ...)
-  local logPattern = params.logPattern
-  local timestampPattern = params.timestampPattern
+  local logPatterns = logging.buildLogPatterns(params.logPatterns, params.logPattern)
+  local timestampPattern = params.timestampPattern or logging.defaultTimestampPattern()
+  local startLevel = params.logLevel or logging.defaultLevel()
 
   local obj = {
     filename = type(params.filename) == "string" and params.filename or "lualogging.log",
@@ -86,10 +87,10 @@ function logging.rolling_file(params, ...)
     if not f then
       return nil, msg
     end
-    local s = logging.prepareLogMsg(logPattern, os.date(timestampPattern), level, message)
+    local s = logging.prepareLogMsg(logPatterns[level], os.date(timestampPattern), level, message)
     f:write(s)
     return true
-  end)
+  end, startLevel)
 end
 
 return logging.rolling_file
